//
//  CarTableViewController.swift
//  Showroom
//
//  Created by Holger Hinzberg on 15.11.15.
//  Copyright © 2015 Holger Hinzberg. All rights reserved.
//

import UIKit

class CarTableViewController: UITableViewController
{
    private var showroom:ShowroomRepository?
    private var selectedCar:ShowroomCar?
    private let detailSegueIdentifier = "CarDetailsSegue"
    
    override func viewDidLoad()
    {
        super.viewDidLoad()
        let sharedDelegate = UIApplication.sharedApplication().delegate
        let appDelegate = sharedDelegate as? AppDelegate
        showroom = appDelegate?.repository
        self.tableView.separatorColor = UIColor.clearColor()
        
        // Die Nachricht refreshTableView
        // des Notification-Centers abonnieren
        let center = NSNotificationCenter.defaultCenter()
        center.addObserver(self, selector: "refreshTableView:",
            name: "refreshTableView", object: nil)
    }

    func refreshTableView(notification:NSNotification)
    {
        print("refreshTableView")
        
        let defaults
        = NSUserDefaults.standardUserDefaults()
        defaults.synchronize()
        
        // Die Tabelle zum erneuten Laden
        // sämtlicher Daten aufrufen
        self.tableView.reloadData()
    }
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    // MARK: - Table view data source

    override func numberOfSectionsInTableView
        (tableView: UITableView) -> Int
    {
        return 1
    }

    override func tableView
        (tableView: UITableView, numberOfRowsInSection section: Int) -> Int
    {
        // Die Anzahl der Objekte in der Tabelle
        // entspricht der Anzahl der Objekte im Repository.
        return self.showroom!.itemsCount()
    }

    override func tableView(tableView: UITableView
        , cellForRowAtIndexPath indexPath:
        NSIndexPath) -> UITableViewCell
    {
        let cell
        = tableView.dequeueReusableCellWithIdentifier(
            "CarCell", forIndexPath: indexPath) as! CarTableViewCell
        
        // Ein Fahrzeug für die angegebene Zeile aus
        // dem Repository holen
        let car
        = self.showroom?.itemAtIndex(indexPath.row)
        
        if car != nil
        {
            cell.setCarForTableViewCell(car!)
        }
        
        // Einen neuen UIView erzeugen
        let backgroundView = UIView()
        backgroundView.backgroundColor
        = UIColor(colorLiteralRed: 0.6, green:
            0.6, blue: 1.0, alpha: 0.4)
        
        // Den View bei Selektion der Zelle
        // als Hintergrund für die Zelle verwenden
        cell.selectedBackgroundView = backgroundView
        
        return cell
    }

    override func tableView(tableView:
        UITableView, didSelectRowAtIndexPath
        indexPath: NSIndexPath)
    {
        // Das gewählte Fahrzeug merken
        self.selectedCar
            = self.showroom?.itemAtIndex(indexPath.row)
        
        // Den Segue für die Detailansicht starten
        self.performSegueWithIdentifier(
            self.detailSegueIdentifier, sender: self)
    }
    
    override func prepareForSegue(segue:
        UIStoryboardSegue, sender: AnyObject?)
    {
        // Ist es der Segue für die Detailansicht?
        if segue.identifier == self.detailSegueIdentifier
        {
            // Das gemerkte Fahrzeug an die
            // Detailansicht übergeben
            if let detailView = segue.destinationViewController
                as? CarDetailViewController
            {
                detailView.car = self.selectedCar
            }
        }
    }

/*
    override func tableView(tableView:
        UITableView, heightForRowAtIndexPath
        indexPath: NSIndexPath) -> CGFloat
    {
        // Alle Zellen sollen 65 Punkte hoch sein
        return 65
    }
*/
    
    override func tableView(tableView:
        UITableView, willDisplayCell cell: UITableViewCell,
        forRowAtIndexPath indexPath: NSIndexPath)
    {
        // Jede zweite Zeile soll gefärbt werden
        if indexPath.row % 2 == 0
        {
            cell.backgroundColor =
            UIColor(colorLiteralRed: 0.9, green: 0.9, blue: 1.0, alpha: 1.0)
        }
        else
        {
            cell.backgroundColor =
            UIColor.whiteColor()
        }
    }
    
    
    /*
    // Override to support conditional editing of the table view.
    override func tableView(tableView: UITableView, canEditRowAtIndexPath indexPath: NSIndexPath) -> Bool {
        // Return false if you do not want the specified item to be editable.
        return true
    }
    */

    /*
    // Override to support editing the table view.
    override func tableView(tableView: UITableView, commitEditingStyle editingStyle: UITableViewCellEditingStyle, forRowAtIndexPath indexPath: NSIndexPath) {
        if editingStyle == .Delete {
            // Delete the row from the data source
            tableView.deleteRowsAtIndexPaths([indexPath], withRowAnimation: .Fade)
        } else if editingStyle == .Insert {
            // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
        }    
    }
    */

    /*
    // Override to support rearranging the table view.
    override func tableView(tableView: UITableView, moveRowAtIndexPath fromIndexPath: NSIndexPath, toIndexPath: NSIndexPath) {

    }
    */

    /*
    // Override to support conditional rearranging of the table view.
    override func tableView(tableView: UITableView, canMoveRowAtIndexPath indexPath: NSIndexPath) -> Bool {
        // Return false if you do not want the item to be re-orderable.
        return true
    }
    */



}
